function basePageSetup() {
	// This will allow IE7 to properly handle a disabled option in a select box.
	// This also fixes a bug that was allowing the user to select a disabled option via the keyboard
	$j("select").find("[disabled]").css("color", "gray");
	
	$j("select").change(function(){
		handleOptionSelect($j(this));
	});
	
	$j("select").keyup(function(){
		handleOptionSelect($j(this));
	});
}

function handleOptionSelect(domSelect) {
	var selected = domSelect.val();
	var disabled = domSelect.find("[value=" + selected + "]").attr("disabled");
	if (disabled || selected == "") {
	        domSelect.find("option:first").attr("selected","selected");
	}

	showHideRequired();
}

function changeServerType(serverType) {
	$("serverNameType").value = serverType;
	
    if (serverType == "domain") {
        OrionCore.setEnabledById("domainName", true);
        OrionCore.setEnabledById("serverName", false);        
        OrionCore.setEnabledById("siteName", true);
        OrionCore.setEnabledById("browse", true);
        
        $("serverName").value = "";
        $("domain").checked = true;
    } else if (serverType == "server") {
        OrionCore.setEnabledById("domainName", false);
        OrionCore.setEnabledById("serverName", true);
        OrionCore.setEnabledById("siteName", false);
        OrionCore.setEnabledById("browse", false);
        
        $("domainName").value = "";
        $("siteName").value = "";
        $("server").checked = true;
    }
    
    valueChanged();
}

function changePasswordFields(checked) {
    if (checked) {
        OrionCore.setEnabledById("password", true);
        OrionCore.setEnabledById("confirmPassword", true);
        
        $("password").value = "";
        $("confirmPassword").value = "";
    } else {
        OrionCore.setEnabledById("password", false);
        OrionCore.setEnabledById("confirmPassword", false);
    }
    
    valueChanged();
}

function validateServerName() {
    var val = $("serverName").value;

    // Check to see if the serverName is empty. If it is then no need to validate the value
    if (!OrionValidate.isNotEmpty(val)) {
        return false;
    }

    // Taken from: http://support.microsoft.com/kb/909264
    // We allow colons to support specifying a port number.
    // BZ 419828 - LDAP Server Name field allows any character.
    var forbidden = [" ", ",", "~", "!", "@", "#", "$", "%", "^", "&", "'", "(", ")", "{", "}", "_"];
    for (var i = 0; i < forbidden.length; i++) {
        if (val.indexOf(forbidden[i]) != -1) {
            return false;
        }
    }

    return true;
}

function validateDomainName() {
    var val = $("domainName").value;

    // Check to see if the domainName is empty. If it is then no need to validate the value
    if (!OrionValidate.isNotEmpty(val)) {
        return false;
    }

    // Taken from: http://support.microsoft.com/kb/909264
    var forbidden = [" ", ",", "~", "!", "@", "#", "$", "%", "^", "&", "'", "(", ")", "{", "}", "_", ":"];
    for (var i = 0; i < forbidden.length; i++) {
        if (val.indexOf(forbidden[i]) != -1) {
            return false;
        }
    }

    return true;
}

function validatePassword() {
	var password = $j.trim($("password").value);
	var confirmPassword = $j.trim($("confirmPassword").value);
	
	if (password == "" || confirmPassword == "") {
		return false;
	}
	
    return password == confirmPassword;
}

function validateCIDRRange() {
	var addrAndMask = $j.trim($("ipCIDRRange").value);
	
    var idx = addrAndMask.indexOf ("/");
	if (OrionValidate.isNotEmpty (addrAndMask) == false || idx == -1 || idx == addrAndMask.length - 1) {
		return false;
	} 
	
	var addr = addrAndMask.substring (0, idx);
	var mask = addrAndMask.substring (idx + 1);
	
	// IPv4 only.
	if (OrionValidate.isValidIpv4CidrSubnet (addr, mask) == false) {
		return false;
	}
	
	var addrBytes = addr.split (".") ;
	var addrByteValue = (addrBytes[0] << 24) + (addrBytes[1] << 16) + (addrBytes[2] << 8) + (addrBytes[3] << 0);
	var addrMaskBits = ~0 << (32 - mask);
	    
    return ((addrByteValue | addrMaskBits) ^ addrMaskBits) == 0;    
}

// TODO: make validateServerName () generic (this is mostly a duplicate)
function validateIwaServer() {
	var iwaServer = $j.trim($("iwaServer").value);

    // Check to see if the serverName is empty. If it is then no need to validate the value
    if (!OrionValidate.isNotEmpty(iwaServer)) {
        return false;
    }

    var forbidden = [" ", ",", "~", "!", "@", "#", "$", "%", "^", "&", "'", "(", ")", "{", "}", "_"];
    for (var i = 0; i < forbidden.length; i++) {
        if (iwaServer.indexOf(forbidden[i]) != -1) {
            return false;
        }
    }

    return true;
    
}


function toggleIDBridge (enabled) {		
	var idBridgeFieldIDs = ["ipCIDRRange", "iwaServer", "iwaServerPrincipalName", "iwaServerPrincipalPassword"];
	for (var idx=0, len=idBridgeFieldIDs.length; idx < len; idx++) { 			
	    OrionCore.setEnabledById (idBridgeFieldIDs[idx], enabled);
    }
	
	valueChanged ();
}

function changeServerType(serverType) {
	$("serverNameType").value = serverType;
	
	if (serverType == "domain") {		
        OrionCore.setEnabledById("domainName", true);
        OrionCore.setEnabledById("serverName", false);        
        OrionCore.setEnabledById("siteName", true);
        OrionCore.setEnabledById("browse", true);
        
        $("serverName").value = "";
        $("domain").checked = true;
	} else if (serverType == "server") {		
        OrionCore.setEnabledById("domainName", false);
        OrionCore.setEnabledById("serverName", true);
        OrionCore.setEnabledById("siteName", false);
        OrionCore.setEnabledById("browse", false);
        
        $("domainName").value = "";
        $("siteName").value = "";
        $("server").checked = true;
	}
	
	valueChanged(); 
}

function sitesLoaded() {
    OrionCore.showPleaseWait(false);
}

var selectedSite = "";
function siteSelected() {
    if (selectedSite != "") $("siteName").value = selectedSite;
}

function getSite() {
    var actionParams = new Array();
    // Loop through all the form elements and add them to the action params
    $j('input:enabled').each(function() {
        if (this.type == "text") {
            actionParams.push(this.name);
            actionParams.push($j(this).val());
        }
    });
    
    actionParams.push("serverNameType");
    actionParams.push($("serverNameType").value);
    actionParams.push("password");
    actionParams.push($("password").value);
    
    selectedSite = "";
    OrionCore.showPleaseWait(true);
    OrionCore.dialogBoxOkHandler = siteSelected;
    OrionCore.showAsyncDialogBox(true, "/saasc/getSite.do", OrionCore.DIALOG_OK_CANCEL, sitesLoaded, actionParams);
}

//Testing the location agains a url pattern
//Pattern: 
//   1 - Starting with http:// (mandatory)
//   2 - Single host part or the first string before the "." 
//       character (10 or host1)
//   3 - parts that compose the host name with the "." character 
//       before the string (.com or .mcafee.com or .eng.mcafee.com 
//       or .10.10.10)
//   4 - path (/~user or /cloud)
function validateLocation(value) {
	 // Checking location with protocol
	 if(value.match(/^[\w]+:\/\//)) {
	     $j("#location_error").html("!! " + message.invalidLocationProtocol);
	     return false;   
	 }

	 // Adding the http part to the location in order to get a full url
	 // address.
	 value = "http://" + value;
 
	 // Checking valid host
	 if(!value.match(/^http:\/\/(((?!\.)(\w|\-){1,})([\.(\w|\-)+]+)?)\/?(.)*/)) {
		 $j("#location_error").html("!! " + message.invalidLocationHost);
	     return false;   
	 }
	 
	 // Ckecking valid path
	 if(!value.match(/^http:\/\/(((?!\.)(\w|\-){1,})([\.(\w|\-)+]+)?)(\/[^\s<>\#%"\,\{\}\\|\\\^\[\]`]+)?$/)) {
	     $j("#location_error").html("!! " + message.invalidLocationPath);
	     return false;   
	 }
	 
 	$j("#location_error").html("");
 	return true;
}

/**
 * To initiate YUI autocomplete component
 * 
 * Example of oEvents = {
     oAC:{
 *     'dataRequestEvent ' = function(_this, sQuery, oResponse){
 *     },
 *     'dataErrorEvent' = function(_this, sQuery, oResponse){
 *     },
 *     ... see the full list in http://developer.yahoo.com/yui/docs/AutoComplete.js.html  -> "// Custom events"
 *   },
 *   oDS:{
 *     'responseParseEvent': function(e){
 *         metaFields = e.response.meta;
 *   }
 * }
 * 
 * @param String sTextfieldName the id of the html textbox
 * @sUrl String the url for the ajax call
 * @oParams Object Extra POST values that want to be passed
 * @oEvents Object of custom events
 * 
 */
function initAutoComplete(sTextfieldName, sUrl, oParams, oEvents) {
	var sTextfieldContainer = sTextfieldName + 'Container'

    // Use an XHRDataSource
    var oDS = new YAHOO.util.XHRDataSource(sUrl);
    oDS.connMethodPost = true;
    // Set the responseType
    oDS.responseType = YAHOO.util.XHRDataSource.TYPE_JSON;
    oDS.responseSchema = {
            resultsList: "response.result",
            metaFields: {
                exception: "response.exception",
                message: "response.message"
            }
    };
    
    if(oEvents.oDS != undefined && typeof oEvents.oDS.responseParseEvent == "function"){
        oDS.subscribe('responseParseEvent', oEvents.oDS.responseParseEvent);
    }
    
    // Instantiate the AutoComplete
    var oAC = new YAHOO.widget.AutoComplete(sTextfieldName, sTextfieldContainer, oDS);
    oAC.queryDelay = 1; // 1 second delay, the default from YUI is 0.1 which is too fast and will create multiple requests
    oAC.forceSelection = true;
    var sParams = "";
    for (i in oParams) {
    	sParams += "&" + i + "=" + oParams[i];
    }

    oAC.generateRequest = function(sQuery) {
    	return 'query=' + sQuery + sParams;
    };
    
    for (x in oEvents.oAC) {
    	if(typeof oEvents.oAC[x] == "function"){
    		try {
    			var event = oAC[x];
    			if(event !=  undefined){
    				event.subscribe(oEvents.oAC[x]);
    			}
    		} catch (e) {
    			// do nothing the supplied function name is not valid
    		}
    		
    	}
    }
};

function displayErrorMessage(error_msg){
	if (error_msg) {
		OrionCore.setDialogBoxTitle("Error");
		OrionCore.showDialogBox(true, error_msg, OrionCore.DIALOG_OK, 200, 300 );
	}
}